@@ -32,9 +32,6 @@ class Q_DECL_HIDDEN LdapClientSearchConfig::Private
 {
 public:
     Private()
-        : useWallet(false)
-        , askWallet(true)
-        , wallet(nullptr)
     {
     }
 
@@ -46,9 +43,9 @@ public:
         }
     }
 
-    bool useWallet;
-    bool askWallet;
-    KWallet::Wallet *wallet;
+    bool useWallet = false;
+    bool askWallet = true;
+    KWallet::Wallet *wallet = nullptr;
 };
 
 Q_GLOBAL_STATIC_WITH_ARGS(KConfig, s_config, (QLatin1String("kabldaprc"), KConfig::NoGlobals))
@@ -69,6 +66,22 @@ LdapClientSearchConfig::~LdapClientSearchConfig()
     delete d;
 }
 
+void LdapClientSearchConfig::clearWalletPassword()
+{
+    if (!d->wallet) {
+        d->wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0);
+    }
+    if (d->wallet) {
+        d->useWallet = true;
+        if (d->wallet->hasFolder(QStringLiteral("ldapclient"))) {
+            //Recreate it.
+            d->wallet->removeFolder(QStringLiteral("ldapclient"));
+            d->wallet->createFolder(QStringLiteral("ldapclient"));
+            d->wallet->setFolder(QStringLiteral("ldapclient"));
+        }
+    }
+}
+
 void LdapClientSearchConfig::readConfig(KLDAP::LdapServer &server, KConfigGroup &config, int j, bool active)
 {
     QString prefix;
